@@ -8,19 +8,21 @@
  * of this file.
  */
 
+/* *INDENT-OFF* */
 #ifndef CHEWING_UTF8_UTILS_H
 #define CHEWING_UTF8_UTILS_H
+/* *INDENT-ON* */
 
 #include <stddef.h>
 
 /* Return length of UTF-8 string */
-int ueStrLen( const char *str );
+int ueStrLen(const char *str);
 
 /* Return bytes of a UTF-8 character */
-int ueBytesFromChar( unsigned char b );
+int ueBytesFromChar(unsigned char b);
 
 /* Return byets of a UTF-8 string until len position */
-int ueStrNBytes( const char *, int );
+int ueStrNBytes(const char *, int);
 
 #define STRNCPY_CLOSE 1
 #define STRNCPY_NOT_CLOSE 0
@@ -32,13 +34,13 @@ int ueStrNBytes( const char *, int );
  * @param[in] n 	The number to copy.
  * @param[in] end
  */
-int ueStrNCpy( char dest[], const char *src, size_t n, int end );
+int ueStrNCpy(char dest[], const char *src, size_t n, int end);
 
 /* Return address from n length after src */
-char *ueStrSeek( char *src, size_t n );
+char *ueStrSeek(char *src, size_t n);
 
 /* Const version of ueStrSeek */
-const char *ueConstStrSeek( const char *src, size_t n );
+const char *ueConstStrSeek(const char *src, size_t n);
 
 /*!
  * Locate a UTF-8 substring from UTF-8 string
@@ -47,7 +49,8 @@ const char *ueConstStrSeek( const char *src, size_t n );
  * @param[in] substr  UTF-8 string that is located in str.
  * @param[in] lsub    Length of substr in bytes.
  */
-const char* ueStrStr( const char *str, size_t lstr,
-                      const char *substr, size_t lsub );
+const char *ueStrStr(const char *str, size_t lstr, const char *substr, size_t lsub);
 
-#endif /* CHEWING_UTF8_UTILS_H */
+/* *INDENT-OFF* */
+#endif                          /* CHEWING_UTF8_UTILS_H */
+/* *INDENT-ON* */
